{% extends "default/pyproject.toml.j2" %}

{% block dependencies %}
dependencies = [
    "{{ plugin_host }}",
    {% for dep in plugin_dependencies | default([]) %}
    "{{ dep }}",
    {% endfor %}
]
{% endblock %}

{% block entry_points %}
[project.entry-points."{{ plugin_host }}.plugins"]
{{ plugin_import_name }} = "{{ import_name }}"
{% endblock %} 