# Package configuration
[package]
min_python = "{{ min_python }}"
{% if max_python %}max_python = "{{ max_python }}"{% endif %}
license = "{{ license }}"
development_status = "{{ development_status }}" 